@@ -148,6 +148,16 @@ public class ConfigurationProperties {
      */
     public static final boolean OX_ACCESS_PERFORM_STALE_CHECKING_DEFAULT = true;
     
+    /**
+     * Specifies for Connections whether to stay signed in (avoids expiration of running sessions to the OX server).
+     */
+    public static final String OX_ACCESS_STAY_SIGNED_IN_PROPERTY = "com.openexchange.usm.ox.stay_signed_in";
+
+    /**
+     * Default value for Connections whether to stay signed in (avoids expiration of running sessions to the OX server).
+     */
+    public static final boolean OX_ACCESS_STAY_SIGNED_IN_DEFAULT = true;
+    
     /**
      * If this property is set to true, usm sets the host header in the login request to the one received from client. To be able to do this, a system property sun.net.http.allowRestrictedHeaders is also set to true
      */
