@@ -141,6 +141,11 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 				requestBody.put(ContactConstants.LAST_NAME, to);
 				requestBody.put(ContactConstants.FIRST_NAME, to);
 				requestBody.put(ContactConstants.DISPLAY_NAME, to);
+				requestBody.put(ContactConstants.EMAIL1, to);
+				requestBody.put(ContactConstants.EMAIL2, to);
+				requestBody.put(ContactConstants.EMAIL3, to);
+				requestBody.put(ContactConstants.SECOND_NAME, to);
+				requestBody.put(ContactConstants.NICKNAME, to);
 				requestBody.put(EMAIL_AUTO_COMPLETE, Boolean.TRUE.toString());
 				requestBody.put(OR_SEARCH, Boolean.TRUE.toString());
 			} catch (JSONException e) {
