@@ -160,7 +160,9 @@ public final class UserParticipantObject implements Serializable {
         result.put(ID, _id);
         result.put(DISPLAY_NAME, _displayName);
         result.put(CONFIRMATION, _confirmation);
-        result.put(CONFIRM_MESSAGE, _confirmMessage);
+        if (!_confirmMessage.isEmpty()) {
+            result.put(CONFIRM_MESSAGE, _confirmMessage);
+        }
         return result;
     }
 }
