@@ -177,6 +177,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     private boolean _passClientHostHeader = false;
 
+    private boolean _staySignedIn = true;
+
     /**
      * Initializes a new {@link OXJSONAccessImpl}.
      *
@@ -184,10 +186,11 @@ public class OXJSONAccessImpl implements OXJSONAccess {
      * @param maxConnections
      * @param connectionTimeout
      * @param performStaleChecking
+     * @param staySignedIn
      * @param passHostHeaderFromClient
      */
-    public OXJSONAccessImpl(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes, String missingObjectErrorCodes) {
-        String error = doActivate(oxJSONURL, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes, missingObjectErrorCodes);
+    public OXJSONAccessImpl(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean staySignedIn, boolean passHostHeaderFromClient, String reloginErrorCodes, String missingObjectErrorCodes) {
+        String error = doActivate(oxJSONURL, maxConnections, connectionTimeout, performStaleChecking, staySignedIn, passHostHeaderFromClient, reloginErrorCodes, missingObjectErrorCodes);
         if (error != null) {
             error = "OXJSONAccess not activated, reason: " + error;
             LOG.error(error);
@@ -205,9 +208,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                 LOG.debug(session + " Logged in, session id = " + result.getSessionID());
             }
         } catch (AuthenticationFailedException e) {
-            if (LOG.isDebugEnabled()) {
-                LOG.debug(session + " Authentication failed", e);
-            }
+            LOG.info(session + " Authentication failed", e);
             throw e;
         } catch (OXCommunicationException e) {
             LOG.warn(session + " Error while authenticating", e);
@@ -277,6 +278,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         method.addParameter("action", "login");
         method.addParameter("name", user);
         method.addParameter("password", password);
+        method.addParameter("staySignedIn", String.valueOf(_staySignedIn));
         for (String header : session.getXRequestHeaders().keySet()) {
             if (CUSTOM_HOST_HEADER.equals(header) && _passClientHostHeader) {
                 method.setRequestHeader(header, session.getXRequestHeaders().get(header));
@@ -433,9 +435,10 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         deactivate("USM OXJSONAccess deactivated");
     }
 
-    private String doActivate(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes, String missingObjectErrorCodes) {
+    private String doActivate(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean staySignedIn, boolean passHostHeaderFromClient, String reloginErrorCodes, String missingObjectErrorCodes) {
         _oxJSONBaseURLasString = oxJSONURL;
         _passClientHostHeader = passHostHeaderFromClient;
+        _staySignedIn = staySignedIn;
         try {
             _oxJSONBaseURL = getURLFromString(oxJSONURL);
         } catch (URIException e) {
