@@ -95,6 +95,9 @@ public class OXJSONAccessActivator extends AbstractUSMActivator {
             boolean performStaleChecking = cm.getProperty(
                 ConfigurationProperties.OX_ACCESS_PERFORM_STALE_CHECKING_PROPERTY,
                     ConfigurationProperties.OX_ACCESS_PERFORM_STALE_CHECKING_DEFAULT, false);
+            boolean staySignedIn = cm.getProperty(
+                ConfigurationProperties.OX_ACCESS_STAY_SIGNED_IN_PROPERTY,
+                    ConfigurationProperties.OX_ACCESS_STAY_SIGNED_IN_DEFAULT, true);
             boolean passHostHeaderFromClient = cm.getProperty(
                 ConfigurationProperties.OX_ACCESS_PASS_HOST_HEADER_FROM_CLIENT,
                     ConfigurationProperties.OX_ACCESS_PASS_HOST_HEADER_FROM_CLIENT_DEFAULT, false);
@@ -104,7 +107,7 @@ public class OXJSONAccessActivator extends AbstractUSMActivator {
             String missingObjectErrorCodes = cm.getProperty(
                     ConfigurationProperties.OX_ACCESS_MISSING_OBJECT_ERROR_CODES_PROPERTY,
                         ConfigurationProperties.OX_ACCESS_MISSING_OBJECT_ERROR_CODES_DEFAULT, false);
-            OXJSONAccess jsonAccess = new OXJSONAccessImpl(accessUrl, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes, missingObjectErrorCodes);
+            OXJSONAccess jsonAccess = new OXJSONAccessImpl(accessUrl, maxConnections, connectionTimeout, performStaleChecking, staySignedIn, passHostHeaderFromClient, reloginErrorCodes, missingObjectErrorCodes);
             registerService(OXJSONAccess.class, jsonAccess);
             LOG.info("OXJSONAccess registered.");
         } catch (USMInvalidConfigurationException e) {
